bcolz has been created by Francesc Alted, so he must be responsible for
all the bugs in the beast.

Also, most of the Python 3 support is a back porting of the work that
Mark Wiebe did for the BLZ package.

Matthew Rocklin and Phillip Cloud contributed conda and binstar recipes.
